@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1996-2019, PostgreSQL Global Development Group
+ * Copyright (c) 1996-2020, PostgreSQL Global Development Group
  * Copyright (c) 2012, OmniTI Computer Consulting, Inc.
  * Portions Copyright (c) 1994, The Regents of the University of California
  * All rights reserved.
@@ -35,8 +35,8 @@
 
 #include "postgres.h"
 #include "funcapi.h"
-#if PG_VERSION_NUM >= 120000
 #include "access/heapam.h"
+#if PG_VERSION_NUM >= 120000
 #include "access/table.h"
 #include "utils/snapmgr.h"
 #else
@@ -97,7 +97,12 @@ pg_dirtyread(PG_FUNCTION_ARGS)
         funcctx = SRF_FIRSTCALL_INIT();
         oldcontext = MemoryContextSwitchTo(funcctx->multi_call_memory_ctx);
         usr_ctx = (pg_dirtyread_ctx *) palloc(sizeof(pg_dirtyread_ctx));
-        usr_ctx->rel = heap_open(relid, AccessShareLock);
+        usr_ctx->rel =
+#if PG_VERSION_NUM >= 120000
+                table_open(relid, AccessShareLock);
+#else
+                heap_open(relid, AccessShareLock);
+#endif
         usr_ctx->reltupdesc = RelationGetDescr(usr_ctx->rel);
         if (get_call_result_type(fcinfo, NULL, &tupdesc) != TYPEFUNC_COMPOSITE)
             ereport(ERROR,
@@ -141,7 +146,11 @@ pg_dirtyread(PG_FUNCTION_ARGS)
     else
     {
         heap_endscan(usr_ctx->scan);
+#if PG_VERSION_NUM >= 120000
+        table_close(usr_ctx->rel, AccessShareLock);
+#else
         heap_close(usr_ctx->rel, AccessShareLock);
+#endif
         SRF_RETURN_DONE(funcctx);
     }
 }
